import * as React from "react";
import { Text } from "react-native";
import { omit } from "ramda";
import { isNilOrEmpty } from "@applicaster/zapp-react-native-utils/reactUtils/helpers";
import {
  textTransform,
  dateFormat,
} from "@applicaster/zapp-react-native-utils/cellUtils";

import { useTextLabel, withFocusedStyles } from "./hooks";
import { withScaledLineHeight } from "./utils";

type Props = {
  style: any;
  label: string;
  transformText: string;
  entry?: any;
  dateTransformEnabled: boolean;
  dateTransform: string;
  [key: string]: any;
};

const withoutLabel = omit(["label"]);

const _Text = ({
  style,
  label,
  entry,
  transformText = "default",
  dateTransformEnabled = false,
  dateTransform,
  ...otherProps
}: Props) => {
  const _label = useTextLabel({ label, entry });

  if (isNilOrEmpty(_label)) {
    return null;
  }

  return (
    <Text
      style={withScaledLineHeight(withFocusedStyles({ style, otherProps }))}
      {...withoutLabel(otherProps)}
    >
      {dateTransformEnabled
        ? dateFormat(dateTransform, label)
        : textTransform(transformText, _label)}
    </Text>
  );
};

export default _Text;
