import React from "react";
import { Text } from "react-native";
import { Provider } from "react-redux";
import TestRenderer from "react-test-renderer";
import configureStore from "redux-mock-store";
import CustomText from "../Text";

const mockStore = configureStore();

const defaultProps = {
  entry: {},
  style: {},
  transformText: "default",
};

const getRenderedText = (label: string, store: any) => {
  const props = { ...{ ...defaultProps, label } };

  const testRenderer = TestRenderer.create(
    <Provider store={store}>
      <CustomText {...props} />
    </Provider>
  );

  return testRenderer.root.findByType(Text).props.children;
};

describe("RTL app: Hebrew text contains english word", () => {
  const textWithFirstEnglishWord = "Word השיר של נועה נועה קירל באירוויזיון";
  const textWithNotFirstEnglishWord = "השיר של נועה נועה קירל באירוויזיון Word";
  const textWithoutEnglishWord = "השיר של נועה נועה קירל באירוויזיון";

  const store = mockStore({
    remoteConfigurations: { localizations: { he: {} } },
    appData: {
      languageCode: "he",
      countryCode: "HE",
    },
  });

  it("Hebrew text contains first english word", () => {
    const renderedText = getRenderedText(textWithFirstEnglishWord, store);
    const desiredText = "\u200fWord\u202c השיר של נועה נועה קירל באירוויזיון";

    expect(renderedText).toEqual(desiredText);
  });

  it("Hebrew text contains not first english word", () => {
    const renderedText = getRenderedText(textWithNotFirstEnglishWord, store);

    expect(renderedText).toEqual(textWithNotFirstEnglishWord);
  });

  it("Hebrew text doesn't contain english word", () => {
    const renderedText = getRenderedText(textWithoutEnglishWord, store);

    expect(renderedText).toEqual(textWithoutEnglishWord);
  });
});

describe("LTR app: English text", () => {
  const englishText = "Test sentence";

  const store = mockStore({
    remoteConfigurations: { localizations: { en: {} } },
    appData: {
      languageCode: "en",
      countryCode: "US",
    },
  });

  it("English text", () => {
    const renderedText = getRenderedText(englishText, store);

    expect(renderedText).toEqual(englishText);
  });
});
